==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/nb.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Saved" : "Lagret",
    "Saving failed:" : "Lagring mislyktes:",
    "File MIME type" : "Filens MIME-type",
    "is" : "er",
    "is not" : "er ikke",
    "matches" : "passer",
    "does not match" : "passer ikke",
    "Example: {placeholder}" : "Eksempel: {placeholder}",
    "File size (upload)" : "Filstørrelse (opplasting)",
    "less" : "mindre",
    "less or equals" : "mindre eller lik",
    "greater or equals" : "større eller lik",
    "greater" : "større",
    "File system tag" : "Filsystem merkelapp",
    "is tagged with" : "er merket med",
    "is not tagged with" : "er ikke merket med",
    "Select tag…" : "Velg merkelapp…",
    "Request remote address" : "Be om ekstern adresse",
    "matches IPv4" : "passer IPv4",
    "does not match IPv4" : "passer ikke IPv4",
    "matches IPv6" : "passer IPv6",
    "does not match IPv6" : "passer ikke IPv6",
    "Request time" : "Ønsket tidspunkt",
    "between" : "mellom",
    "not between" : "ikke mellom",
    "Start" : "Start",
    "End" : "Slutt",
    "Select timezone…" : "Velg tidssone ...",
    "Request URL" : "Ønsk en URL",
    "Predefined URLs" : "Forhåndsdefinerte URLer",
    "Files WebDAV" : "Filer WebDAV",
    "Request user agent" : "Ønsket brukeragent",
    "Sync clients" : "Synkroniseringsklienter",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Skrivebordsklient",
    "User group membership" : "Brukerens gruppemedlemsskap",
    "is member of" : "er medlem av",
    "is not member of" : "er ikke medlem av",
    "The given operator is invalid" : "Den angitte operatøren er ugyldig",
    "The given regular expression is invalid" : "Det angitte regulære uttrykket er ugyldig",
    "The given file size is invalid" : "Den angitte filstørrelsen er ugyldig",
    "The given tag id is invalid" : "Den angitte merkelappen er ugyldig",
    "The given IP range is invalid" : "Den angitte ip rangen er ugyldig",
    "The given IP range is not valid for IPv4" : "Den angitte ip rangen er ugyldig for IPv4",
    "The given IP range is not valid for IPv6" : "Den angitte ip rangen er ugyldig for IPv6",
    "The given time span is invalid" : "Den angitte tidsrammen er ugyldig",
    "The given start time is invalid" : "Den angitte starttiden er ugyldig",
    "The given end time is invalid" : "Den angitte slutttiden er ugyldig",
    "The given group does not exist" : "Den angitte brukergruppen finnes ikke",
    "Check %s is invalid or does not exist" : "Sjekk %s er ugyldig eller finnes ikke",
    "Operation #%s does not exist" : "Handlingen #%s finnes ikke",
    "Operation %s does not exist" : "Handlingen %s finnes ikke",
    "Operation %s is invalid" : "Handlingen %s er ugyldig",
    "Check %s does not exist" : "Sjekk %s finnes ikke",
    "Check %s is invalid" : "Sjekk %s er ugyldig",
    "Check #%s does not exist" : "Sjekk #%s finnes ikke",
    "Workflow" : "Arbeidsflyt",
    "Files workflow engine" : "Arbeidsflytmotor for Files-programmet",
    "Open documentation" : "Åpne dokumentasjonen",
    "Add rule group" : "Legg til regelgruppe",
    "Short rule description" : "Kort beskrivelse av regel",
    "Add rule" : "Legg til regel",
    "Reset" : "Tilbakestill",
    "Save" : "Lagre",
    "Saving…" : "Lagrer ...",
    "Loading…" : "Laster ...",
    "Successfully saved" : "Lagret",
    "File mime type" : "Filens MIME-type"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/nb.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Den angitte operatøren er ugyldig",
    "The given regular expression is invalid" : "Det angitte regulære uttrykket er ugyldig",
    "The given file size is invalid" : "Den angitte filstørrelsen er ugyldig",
    "The given tag id is invalid" : "Den angitte merkelappen er ugyldig",
    "The given IP range is invalid" : "Den angitte ip rangen er ugyldig",
    "The given IP range is not valid for IPv4" : "Den angitte ip rangen er ugyldig for IPv4",
    "The given IP range is not valid for IPv6" : "Den angitte ip rangen er ugyldig for IPv6",
    "The given time span is invalid" : "Den angitte tidsrammen er ugyldig",
    "The given start time is invalid" : "Den angitte starttiden er ugyldig",
    "The given end time is invalid" : "Den angitte slutttiden er ugyldig",
    "The given group does not exist" : "Den angitte brukergruppen finnes ikke",
    "Operation #%s does not exist" : "Handlingen #%s finnes ikke",
    "Operation %s does not exist" : "Handlingen %s finnes ikke",
    "Operation %s is invalid" : "Handlingen %s er ugyldig",
    "Check %s does not exist" : "Sjekk %s finnes ikke",
    "Check %s is invalid" : "Sjekk %s er ugyldig",
    "Check #%s does not exist" : "Sjekk #%s finnes ikke",
    "Check %s is invalid or does not exist" : "Sjekk %s er ugyldig eller finnes ikke",
    "Predefined URLs" : "Forhåndsdefinerte URLer",
    "Files WebDAV" : "Filer WebDAV",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Skrivebordsklient",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook tillegg",
    "File name" : "Filnavn",
    "is" : "er",
    "is not" : "er ikke",
    "matches" : "passer",
    "does not match" : "passer ikke",
    "File MIME type" : "Filens MIME-type",
    "File size (upload)" : "Filstørrelse (opplasting)",
    "less" : "mindre",
    "less or equals" : "mindre eller lik",
    "greater or equals" : "større eller lik",
    "greater" : "større",
    "Request remote address" : "Be om ekstern adresse",
    "matches IPv4" : "passer IPv4",
    "does not match IPv4" : "passer ikke IPv4",
    "matches IPv6" : "passer IPv6",
    "does not match IPv6" : "passer ikke IPv6",
    "File system tag" : "Filsystem-merkelapp",
    "is tagged with" : "er merket med",
    "is not tagged with" : "er ikke merket med",
    "Request URL" : "Ønsk en URL",
    "Request time" : "Ønsket tidspunkt",
    "between" : "mellom",
    "not between" : "ikke mellom",
    "Request user agent" : "Ønsket brukeragent",
    "User group membership" : "Brukerens gruppemedlemsskap",
    "is member of" : "er medlem av",
    "is not member of" : "er ikke medlem av",
    "Short rule description" : "Kort beskrivelse av regel",
    "Add rule" : "Legg til regel",
    "Reset" : "Tilbakestill",
    "Save" : "Lagre",
    "Saving…" : "Lagrer…",
    "Group list is empty" : "Gruppeliste er tom",
    "Unable to retrieve the group list" : "Kunne ikke hente gruppelisten",
    "Saved" : "Lagret",
    "Saving failed:" : "Lagring mislyktes:",
    "Add rule group" : "Legg til regelgruppe",
    "Example: {placeholder}" : "Eksempel: {placeholder}",
    "Select tag…" : "Velg merkelapp…",
    "Start" : "Start",
    "End" : "Slutt",
    "Select timezone…" : "Velg tidssone…",
    "Sync clients" : "Synkroniseringsklienter",
    "Workflow" : "Arbeidsflyt",
    "Files workflow engine" : "Arbeidsflytmotor for filer",
    "Open documentation" : "Åpne dokumentasjonen",
    "Loading…" : "Laster…",
    "Tag management" : "Merkelapphåndtering"
},
"nplurals=2; plural=(n != 1);");
